@@ -29,17 +29,22 @@ lambda=NULL, nfolds=10, foldid, plot.it=TRUE, se=TRUE, n.cores=2, trace=FALSE, p
     all.folds <- cv.folds(n, K)
     else all.folds <- foldid
     if(parallel){
-    registerDoParallel(cores=n.cores)
+    cl <- eval(parse(text="parallel:::makeCluster(n.cores)"))
+    registerDoParallel(cl)
     i <- 1  ###needed to pass R CMD check with parallel code below
     residmat <- foreach(i=seq(K), .combine=cbind) %dopar% {
       omit <- all.folds[[i]]
 ### changed 5/20/2013 fixed theta
-      fitcv <- do.call("glmregNB", list(formula, data[-omit,], weights[-omit], offset=offset[-omit], nlambda=nlambda, lambda=lambda, theta.est=FALSE, theta0=glmregNB.obj$theta, ...))
+      if(!is.null(offset)){
+         offsetnow <- offset[- omit]
+         newoffset <- offset[omit]
+         }else offsetnow <- newoffset <- NULL
+      fitcv <- do.call("glmregNB", list(formula, data[-omit,], weights[-omit], offset=offsetnow, nlambda=nlambda, lambda=lambda, theta.est=FALSE, theta0=glmregNB.obj$theta, ...))
 ### remove the first column, which is for intercept
       fitcv$terms <- NULL ### logLik requires data frame if terms is not NULL
-      logLik(fitcv, newx=X[omit,-1, drop=FALSE], Y[omit], weights=weights[omit], offset=offset[omit])
+      logLik(fitcv, newx=X[omit,-1, drop=FALSE], Y[omit], weights=weights[omit], offset=newoffset)
    }
-   stopImplicitCluster()
+   eval(parse(text="parallel:::stopCluster(cl)"))
     }
     else{
           residmat <- matrix(NA, nlambda, K)
@@ -48,10 +53,14 @@ lambda=NULL, nfolds=10, foldid, plot.it=TRUE, se=TRUE, n.cores=2, trace=FALSE, p
          cat("\n CV Fold", i, "\n\n")
        omit <- all.folds[[i]]
  ### changed 5/20/2013 fixed theta
-       fitcv <- do.call("glmregNB", list(formula, data[-omit,], weights[-omit], offset[-omit], nlambda=nlambda,  lambda=lambda, theta.est=FALSE, theta0=glmregNB.obj$theta, trace=trace, ...))
+      if(!is.null(offset)){
+         offsetnow <- offset[- omit]
+         newoffset <- offset[omit]
+         }else offsetnow <- newoffset <- NULL
+       fitcv <- do.call("glmregNB", list(formula, data[-omit,], weights[-omit], offset=offsetnow, nlambda=nlambda,  lambda=lambda, theta.est=FALSE, theta0=glmregNB.obj$theta, trace=trace, ...))
  ### remove the first column, which is for intercept
        fitcv$terms <- NULL ### logLik requires data frame if terms is not NULL
-       residmat[, i] <- logLik(fitcv, newx=X[omit,-1, drop=FALSE], Y[omit], weights=weights[omit], offset=offset[omit])
+       residmat[, i] <- logLik(fitcv, newx=X[omit,-1, drop=FALSE], Y[omit], weights=weights[omit], offset=newoffset)
      }
     }
    cv <- apply(residmat, 1, mean)
